C
      subroutine tconind(yr,mm,day,idn,rz,sf,rsn,nmonth,nind)
c----------------------------------------------------------------
C TLG......................................................... May, 2017
C      nind =0 (DEFAULT): SSN1 => rz(3); F10.7 => sf(3) 
C      nind =1 ssn1_12.dat  SSN1  =>  rz(3); F10.7  =>  sf(3) 
C	 nind =2 ssn2_12.dat  SSN2 converted to SSN1  =>  rz(3); F10.7  => sf(3)
C	 nind =3 f107_12.dat  F10.7	 =>  sf(3) converted to SSN1  =>  rz(3) 
C	 nind =4 geci_12.dat  GEC => rz(3); F10.7  => sf(3)
C	 nind =5 teci_12.dat  TEC => rz(3); F10.7  => sf(3)
C	 nind =6 igin_12.dat  IG  => rz(3); F10.7  => sf(3)
C	 nind =7 mgii_12.dat  MgII => rz(3); F10.7  => sf(3)
C	 nind =8 lyma_12.dat  Lyman-alpha => rz(3); F10.7  => sf(3)
C Ref. T.L.Gulyaeva et al., 2017. TEC proxy index of solar activity for the
C      International Reference Ionosphere IRI and its extension to 
C      Plasmasphere IRI-PLAS model.
C
c input:        yr,mm,day       year(yyyy),month(mm),day(dd)
c               idn             day of year(ddd)
c               nind            type of solar proxy index
c output:       rz(3)           12-month-smoothed solar sunspot number or proxy index specified by user
c               sf(3)           12-month-smoothed solar radio flux F10.7
c               rsn             interpolation parameter
c               nmonth          previous or following month depending
c                               on day
c
c rz(1), sf(1) contain the indices for the month mm and rz(2), sf(2)
c for the previous month (if day less than 15) or for the following
c month (otherwise). These indices are for the mid of the month. The
c indices for the given day are obtained by linear interpolation and
c are stored in rz(3) and sf(3).
c
c the indices are obtained from the indices files according to nind  
c 
c----------------------------------------------------------------
      integer      yr, mm, day
      integer      nind
C*      real         ionoindx(734),indrz(734)
      real         sf(3),rz(3)
     	character*4  xxpr,yypr
		COMMON /BXY/xxpr,yypr

c
C
c rz(3) is read from xxpr_12.dat file (xxpr is defined according to nind) 
c and the sf(3) solar radio flux index is determined from yypr_12.dat file 
c which have the following structure: 
c day, month, year of the last update of this file,
c start month, start year, end month, end year,
c the 12 indices (13-months running mean) for the first year, 
c the 12 indices for the second year and so on until the end year,
c The inteporlation procedure also requires the proxy index values for
c the month preceeding the start month and the proxy index values for the
c month following the end month. These values are also included in 
c xxpr_12.dat and yypr_12.dat file.
c 
c Input of nind=0 (default) means that the given index is the 13-months-running mean of 
c SSN1 (former Rz12) and the solar radio flux (F10.7). The close correlation between Rz12 
c and other solar proxies is used to derive the rz(3) and sf(3) indices.
c
c
c The computation of the 13-month-running mean for month M requires the
c indices for the six months preceeding M and the six months following 
C M (month: M-6, ..., M+6). To calculate the current running mean one 
C therefore requires predictions of the index for the next six months. 
C Starting from six months before the UPDATE DATE (listed at the top of 
c the file) and onward the indices are therefore based on indices 
c predictions.
C
C Start to determine prec. month or next month:
      midm=15
        if(mm.eq.2) midm=14
        call MODA(0,yr,mm,midm,idd1,nrdaym)
        if(day.lt.midm) goto  926
                imm2=mm+1
                if(imm2.gt.12) then
                        imm2=1
                        iyy2=yr+1
                        idd2=380
                        if(yr/4*4.eq.yr) idd2=381
                else
                        iyy2=yr
                        midm=15
                        if(imm2.eq.2) midm=14
                        call MODA(0,iyy2,imm2,midm,IDD2,nrdaym)
                endif
                goto 927
  926            imm2=mm-1
                if(imm2.lt.1) then
      		          imm2=12
                        idd2=-16
                        iyy2=yr-1
                else
                        iyy2=yr
                        midm=15
                        if(imm2.eq.2) midm=14
                        call MODA(0,iyy2,imm2,midm,IDD2,nrdaym)
                endif
  927	nmonth=imm2
C
C Default case:
C
      IF (nind.eq.0) THEN
	xxpr='ssn1'
	call subproxy(xxpr,yr,mm,iyy2,imm2,rz)  !read SSN1
	yypr='f107'
	call subproxy(yypr,yr,mm,iyy2,imm2,sf)  !read F10.7
	goto 33
      ENDIF
C
        select case (nind)
C 
	case (1)   ! read SSN1 => calculate F10.7
C        
    1	xxpr='ssn1'	     
      call subproxy(xxpr,yr,mm,iyy2,imm2,rz)  !read SSN1_12
C+      sf(1)=0.9066*rz(1)+62.6645
C+      sf(2)=0.9066*rz(2)+62.6645
	yypr='f107'
	call subproxy(yypr,yr,mm,iyy2,imm2,sf)  !read F10.7
	goto 33
C 
	case (2)   ! read SSN2 => calculate SSN1 => calculate F10.7
C        
    2	xxpr='ssn2'	     
      call subproxy(xxpr,yr,mm,iyy2,imm2,rz)  !read SSN2_12
	rz(1)=0.7*rz(1)
	rz(2)=0.7*rz(2)
C+      sf(1)=0.9066*rz(1)+62.6645
C+      sf(2)=0.9066*rz(2)+62.6645
	yypr='f107'
	call subproxy(yypr,yr,mm,iyy2,imm2,sf)  !read F10.7
	goto 33
C        
	case (3)   ! read F10.7 => calculate SSN1
C 
    3	yypr='f107'	     
      call subproxy(yypr,yr,mm,iyy2,imm2,sf)  !read F10.7_12
	rz(1)=1.076*sf(1)-65.7817 
	rz(2)=1.076*sf(2)-65.7817  
	if (rz(1).lt.0.) rz(1)=0.
	if (rz(2).lt.0.) rz(2)=0.
	goto 33
C 
	case (4)   ! read GEC proxy => calculate F10.7
C 
    4	xxpr='geci'	     
      call subproxy(xxpr,yr,mm,iyy2,imm2,rz)  !read GEC_12
C+      sf(1)=0.9517*rz(1)+60.8983
C+      sf(2)=0.9517*rz(2)+60.8983
	yypr='f107'
	call subproxy(yypr,yr,mm,iyy2,imm2,sf)  !read F10.7
	goto 33
C 
	case (5)   ! read TEC proxy => calculate F10.7
C 
    5	xxpr='teci'	     
      call subproxy(xxpr,yr,mm,iyy2,imm2,rz)  !read TEC_12
C+      sf(1)=1.0749*rz(1)+64.1046
C+      sf(2)=1.0749*rz(2)+64.1046
	yypr='f107'
	call subproxy(yypr,yr,mm,iyy2,imm2,sf)  !read F10.7
	goto 33
C 
	case (6)   ! read IG => calculate F10.7
C 
    6	xxpr='igin'	     
      call subproxy(xxpr,yr,mm,iyy2,imm2,rz)  !read IG_12
C+      sf(1)=0.0027*rz(1)**2.+0.4531*rz(1)+72.4891
C+      sf(2)=0.0027*rz(2)**2.+0.4531*rz(2)+72.4891
	yypr='f107'
	call subproxy(yypr,yr,mm,iyy2,imm2,sf)  !read F10.7
      goto 33
C 
	case (7)   ! read MgII proxy => calculate F10.7
C 
    7	xxpr='mgii'	     
      call subproxy(xxpr,yr,mm,iyy2,imm2,rz)  !read MgII_12
C+      sf(1)=0.0014*rz(1)**2.+0.6804*rz(1)+68.7343
C+      sf(2)=0.0014*rz(2)**2.+0.6804*rz(2)+68.7343
	yypr='f107'
	call subproxy(yypr,yr,mm,iyy2,imm2,sf)  !read F10.7
	goto 33
C 
	case (8)   ! read Lyman-alpha proxy => calculate F10.7
C 
    8	xxpr='lyma'	     
      call subproxy(xxpr,yr,mm,iyy2,imm2,rz)  !read Lym-a_12
C+      sf(1)=0.001*rz(1)**2.+0.6572*rz(1)+63.789
C+      sf(2)=0.001*rz(2)**2.+0.6572*rz(2)+63.789
	yypr='f107'
	call subproxy(yypr,yr,mm,iyy2,imm2,sf)  !read F10.7
	goto 33
C+++++++
      end select 
   33	continue
        if(day.lt.midm) goto 34
      rsn=(idn-idd1)*1./(idd2-idd1)
      rz(3)=rz(1)+(rz(2)-rz(1))*rsn
      sf(3)=sf(1)+(sf(2)-sf(1))*rsn
	goto 35
C
   34	rsn=(idn-idd2)*1./(idd1-idd2)
      rz(3)=rz(2)+(rz(1)-rz(2))*rsn
      sf(3)=sf(2)+(sf(1)-sf(2))*rsn
   35	return
      end
C
C
C
      subroutine subproxy(xxxx,kyr1,kmn1,kyr2,kmn2,zz)
C
C TLG....................................................May, 2017
C Subroutine to read 12-monthly smoothed solar proxy data
C for given year=kyr1 and month = kmn1 
C kyr2,kmn2 denoted either preceding month or the following month
C zz(1) results for the given month kyr1,kmn1, and zz(2) for kyr2,kmn2  
C
	CHARACTER*4 xxxx
	CHARACTER*12 infile
	real zz(3),dat(12)
	infile='xxxx_12.dat'
	infile(1:4)=xxxx
	zz(1)=-1.0
	zz(2)=-1.0
	zz(3)=0.0
C
      open(unit=12,file=infile,ERR=10,status='old')
		GOTO 20
   10 write(*,*) ' CANNOT FIND THE FILE ',infile,' EXECUTION TEMINATED.'
      PAUSE  ' '
      STOP
   20 CONTINUE	 
c Read the update date, the start date and the end date (mm,yyyy)
c 
          read(12,*) iupd,iupm,iupy
          read(12,*) imst,iyst, imend, iyend
c
      if ((kyr1.lt.iyst).or.(kyr1.gt.iyend)) then
      write (*,*) ' REQUIED YEAR OUTSIDE OF DATA PERIOD IN THE FILE '
	+,infile,' EXECUTION TEMINATED.'
	 pause ' '
      STOP
	endif
c
c Read all year and input values
   11 read(12,*,err=15,end=15) kyyyy, (dat(i),i=1,12)
      IF (kyr1.eq.kyr2) THEN					 
	         if (kyyyy.eq.kyr1) then
	         zz(1)=dat(kmn1)
	         zz(2)=dat(kmn2)
	         goto 16
	                  else
               goto 11
	         endif
      	ENDIF								  
            IF (kyr1.lt.kyr2) THEN	   		 !+
C kyr1 < kyr2
	        IF (kyr1.eq.kyyyy) THEN			  !
          	zz(1)=dat(kmn1)
	          if (kyr2.gt.iyend) then		  !!
                zz(2)=zz(1)
              	goto 16
             	  else							  !!
              read(12,*,err=15,end=15) kyyyy,zz(2)
                goto 16
                endif   	 					  !!
          	ELSE							  !
              goto 11
		    ENDIF                             !
			                  ELSE		 	   !+
C kyr2 < kyr1
             IF (kyr2.ge.iyst) THEN			  !
C  kyr2 > iyst    		   
	       if (kyr2.eq.kyyyy) then			  !!
          	zz(2)=dat(kmn2)
                read(12,*,err=15,end=15) kyyyy,zz(1)
                goto 16
          	else							  !!
              goto 11
		    endif                             !!
	                           ELSE           !
C kyr2 < iyst
              if (kyr1.eq.kyyyy) then			!!!
			zz(1)=dat(kmn1)
			zz(2)=zz(1)
			               else				!!!
              goto 11
                          endif				!!!					    	
       	ENDIF								   !!
		         ENDIF                         !+
C
  15	write(*,*) 'End-of-file ',infile
	pause ' '
	stop
C	
   16     close(unit=12)
            return
            end
c ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
